==> sflphone_1.2.3.orig.tar.gz: sflphone-1.2.3/daemon/src/eventthread.h <==
/*
 *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
 *  Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  If you modify this program, or any covered work, by linking or
 *  combining it with the OpenSSL project's OpenSSL library (or a
 *  modified version of that library), containing parts covered by the
 *  terms of the OpenSSL or SSLeay licenses, Savoir-Faire Linux Inc.
 *  grants you additional permission to convey the resulting work.
 *  Corresponding Source for a non-source form of such a combination
 *  shall include the source code for the parts of OpenSSL used as well
 *  as that of the covered work.
 */

#ifndef EVENT_THREAD_H_
#define EVENT_THREAD_H_

#include "noncopyable.h"
#include <pthread.h>

class VoIPLink;

/**
 * @file eventthread.h
 * @brief Runs thread which listens to VoIP events continuously
 */

class EventThread {
    public:
        EventThread(VoIPLink* link);
        ~EventThread();
        // spawns thread
        void start();

    private:
        NON_COPYABLE(EventThread);
        // VoIPLink is the object being called by getEvents() method
        VoIPLink* link_;
        pthread_t thread_;
        void run();
        static void *runCallback(void *);
};

#endif // EVENT_THREAD_H__

==> sflphone_1.3.0.orig.tar.gz: sflphone-1.3.0/daemon/src/eventthread.h <==
/*
 *  Copyright (C) 2004-2013 Savoir-Faire Linux Inc.
 *  Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  If you modify this program, or any covered work, by linking or
 *  combining it with the OpenSSL project's OpenSSL library (or a
 *  modified version of that library), containing parts covered by the
 *  terms of the OpenSSL or SSLeay licenses, Savoir-Faire Linux Inc.
 *  grants you additional permission to convey the resulting work.
 *  Corresponding Source for a non-source form of such a combination
 *  shall include the source code for the parts of OpenSSL used as well
 *  as that of the covered work.
 */

#ifndef EVENT_THREAD_H_
#define EVENT_THREAD_H_

#include "noncopyable.h"
#include <thread>

class VoIPLink;

/**
 * @file eventthread.h
 * @brief Runs thread which listens to VoIP events continuously
 */

class EventThread {
    public:
        EventThread(VoIPLink* link);
        ~EventThread();
        // spawns thread
        void start();
        void join();

    private:
        NON_COPYABLE(EventThread);
        // VoIPLink is the object being called by getEvents() method
        VoIPLink* link_;
        std::thread thread_;
        void run();
};

#endif // EVENT_THREAD_H__
